@@ -7,7 +7,7 @@ use warnings 'all';
 ###########################################################################
 # METADATA
 our $AUTHORITY = 'cpan:DOUGDUDE';
-our $VERSION   = '0.13_003';
+our $VERSION   = '0.13_004';
 
 ###########################################################################
 # MOOSE
@@ -410,7 +410,7 @@ sub _parse_response_body {
 	if (!defined ${$status_r} && $response->headers->content_is_html) {
 		# This is HTML, so what we will do is strip all surrounding tags
 		# since it looks like a valid status wasn't found
-		${$message_r} =~ s{\s* < [^>]+ > \s*}{}msx; # XXX: Fix me later
+		${$message_r} =~ s{\s* < [^>]+ > \s*}{}gmsx; # XXX: Fix me later
 
 		# Reparse for the status code
 		if (${$message_r} =~ m{\A (?:[^a-z]+ \s+)? (OK|WARNING|CRITICAL|UNKNOWN)}msx) {
@@ -595,7 +595,7 @@ Nagios::Plugin::OverHTTP - Nagios plugin to check over the HTTP protocol.
 
 =head1 VERSION
 
-Version 0.13_003
+Version 0.13_004
 
 =head1 SYNOPSIS
 
